"""
    __logger__.py
    ~~~~~~~~~~~~~

    Simple defines the logger used across the module.

"""
__all__ = ["logger"]

import logging

logger = logging.getLogger("sxcu")  # pylint: disable=invalid-name
S_HANDLER = logging.StreamHandler()
S_HANDLER.setLevel(logging.DEBUG)
S_FORMAT = logging.Formatter(
    "%(asctime)s - %(name)s - %(levelname)s - %(message)s",
)
S_HANDLER.setFormatter(S_FORMAT)
logger.addHandler(S_HANDLER)



"""
    SXCU
    ~~~~

    Python API wrapper for sxcu.net.

    :copyright: Copyright 2020 by Naveen M K
    :license: Apache-2.0 , see LICENSE for details.

"""
from .__version__ import *  # noqa F401
from .sxcu import SXCU, OGProperties  # noqa F401



"""Custom Exeeption declarations.
"""


class SXCUError(Exception):
    """SXCUError A error which will be raised when the returned status
    code isn't right.

    See error_codes and message list for more information in
    https://sxcu.net.
    """
